import { JoinPoint, MidwayDecoratorService, REQUEST_OBJ_CTX_KEY, createCustomMethodDecorator } from '@midwayjs/core';
import { get } from 'lodash';
import { ElasticsearchService } from '../service/elasticsearch';
export const SYNC_ELASTICSEARCH_KEY = 'decorator:sync_elasticsearch';
export const syncElasticSearch = (options?: any) => {
  return createCustomMethodDecorator(SYNC_ELASTICSEARCH_KEY, options);
};

export const SyncElasticSearchInit = (decoratorService: MidwayDecoratorService) => {
  decoratorService.registerMethodHandler(SYNC_ELASTICSEARCH_KEY, options => {
    return {
      around: async (joinPoint: JoinPoint) => {
        const instance = joinPoint.target;
        const ctx = instance[REQUEST_OBJ_CTX_KEY];
        const methodName = options.propertyName;
        const result = await joinPoint.proceed(...joinPoint.args);
        const controller = await ctx.requestContext.getAsync(options.target);
        const modelName = get(controller, 'service.model.modelName');
        try {
          // 不影响后续进行
          let res;
          if (methodName === 'create' || methodName === 'update') {
            const es = await ctx.requestContext.getAsync(ElasticsearchService);
            res = await es.asyncData(modelName, result);
          } else if (methodName === 'delete') {
            const id = get(ctx.request, 'params.id');
            const es = await ctx.requestContext.getAsync(ElasticsearchService);
            res = await es.delete(modelName, id);
          }
          console.log(res);
        } catch (error) {
          console.log(error);
        }
        return result;
      },
    };
  });
};
